PyGame EXTension
=========
Small python extension (written in C) for pygame.Surface manipulation.


## Dependecies
 * Python 2.5.4+
 * pygame 1.8+
 * SDL 1.2+

## Installation (Fedora linux)

    yum install pygame-devel python-devel SDL-devel
    git clone https://github.com/gindar/pgext.git
    cd pgext
    su -c python setup.py install

## Links

http://zamraky.cz/projects/pgext/
